#!/bin/sh
# 

trap "on_error; exit 1" INT QUIT TERM

innovaphone_tmp=""
innovaphone_app_tmp=""
app=""
xml_tmp=""
installed_packages=""
custom_declared=0

source ./functions.sh

function on_exit()
{
    if [ -n "${innovaphone_tmp}" ]; then
        rm -R -f ${innovaphone_tmp}
    fi
    if [ -n "${innovaphone_app_tmp}" ]; then
        rm -R -f ${innovaphone_app_tmp}
    fi
    if [ -n "${xml_tmp}" ]; then
        rm -f ${xml_tmp}
    fi
    on_exit_app
    if [ ${custom_declared} -eq 1 ]; then
        on_exit_custom
    fi
}

function on_error()
{
    if [ -n "${installed_packages}" ]; then
        apt-get -y --force-yes purge ${installed_packages}
	    apt-get autoremove
    fi
    if [ -n "${innovaphone_tmp}" ]; then
        /etc/init.d/lighttpd stop
        cp -p -R ${innovaphone_tmp}/* /var/www/innovaphone
        /etc/init.d/lighttpd start
    fi
    if [ -n "${innovaphone_app_tmp}" ]; then
        cp -p -R ${innovaphone_app_tmp}/* /var/www/innovaphone/apps/${app}
    fi
    if [ -n "${xml_tmp}" ]; then
        cp -p ${xml_tmp} /var/www/innovaphone/apps/${app}.xml
    fi
    on_error_app
    if [ ${custom_declared} -eq 1 ]; then
        on_error_custom
    fi
    on_exit
}


exseq_tmp=""

function on_exit_app()
{
    if [ -n "${exseq_tmp}" ]; then
        rm -f ${exseq_tmp}
    fi
}

function on_error_app()
{
    if [ -n "${exseq_tmp}" ]; then
        cp -p ${exseq_tmp} /home/postgres/restore/
    fi
}
# if your're using this script, you have to provide an on_error function
# and you must have included functions.sh

# $1 either install or upgrade
# $2 empty to install all packages inside 'packages' or a string with package names, e.g. "php5-pgsql php5-gd"
function install_packages() 
{
    sources_list="/etc/apt/sources.list"
    if [ -d packages ]; then
        if [ -n "$(dpkg -l '*' | grep '^i[^iU]')" -o -n "$(dpkg -C)" ]; then
            dpkgl=`dpkg -l '*' | grep '^i[^iU]'`
            dpkgc=`dpkg -C`
            log_error "Debian packages can't be installed: ${dpkgl} ${dpkgc}" 
            on_error
            exit 1
        fi
        cd packages
        if [ "$2" ]; then
            installed_packages="$2"
        else
            installed_packages=`ls -1 *.deb | cut -d"_" -f1 | xargs`
        fi
        cd ..
        if [ ! -n "${installed_packages}" ]; then
            log_msg "No debian packages to install"
        else
            log_msg "Install debian packages ${installed_packages}"
            apt-ftparchive packages packages/ > packages/Packages
            sed -e 's/packages\///' -i packages/Packages
            gzip -9c packages/Packages > packages/Packages.gz
            rm packages/Packages
            mv packages/Packages.gz /var/cache/apt/archives
            mv packages/*.deb /var/cache/apt/archives
            mv ${sources_list} ${sources_list}.tmp
            echo "deb file:///var/cache/apt/archives /" > ${sources_list}
            apt-get update
            tmp=""
            if [ "$1" = "install" ]; then
                installed_tmp=""
                for d in $installed_packages; do
                    p_installed=`dpkg -l | egrep -oe "[a-zA-Z]{2}[ ]*$d"`
                    if [ -z "$p_installed" ]; then
                        installed_tmp="$installed_tmp $d"
                    else
                        log_msg "Package $d already installed"
                    fi
                done
                apt-get -y --force-yes install ${installed_packages}
                apt_res=$?
                installed_packages=$installed_tmp
            elif [ "$1" = "upgrade" ]; then
                installed_packages=""
                tmp=`apt-get -y --force-yes upgrade`
                apt_res=$?
                echo $tmp
            fi
            apt-get clean
            mv ${sources_list}.tmp ${sources_list}
            if [ ! ${apt_res} -eq 0 ]; then
                log_error "Installation of debian packages failed"
                on_error
                exit 1
            fi
            if echo $tmp | grep "The following packages have been kept back" >/dev/null
            then
                if [ "$1" = "upgrade" ]; then
                    missing=`echo $tmp | sed 's/.*have been kept back: \+\(.*\) \+The \+following \+packages \+will \+be \+upgraded.*/\1/'`
                    log_msg "Some package dependencies are missing!"
                    tmp_file="/var/www/innovaphone/log/missing_packages.log"			 
                    echo ${missing} > $tmp_file
                    chmod 755 $tmp_file
                    chown www-data:www-data $tmp_file
                fi
            fi
        fi
    else
        log_msg "No debian packages to install"
    fi
}

app=innovaphone-exchange
chmod 755 *.sh
./check_platform.sh platform
if [ $? -ne 0 ]; then
    exit 1
fi
./check_version.sh 120014 /var/www/innovaphone/apps/innovaphone-exchange/version 1 1 innovaphone-exchange 12r1/linux/innovaphone-exchange
if [ ! $? -eq 0 ]; then
    exit 1
fi
 
 
innovaphone_app_tmp=`mktemp -d /tmp/innovaphone_app_XXXXXXXX`
./php_template.sh innovaphone-exchange www-data web/innovaphone-exchange /var/www/innovaphone/apps/innovaphone-exchange ${innovaphone_app_tmp}
 
 
tmp_dir=""

# will be called in on_error, automatically added by make.sh
function on_error_custom() 
{
    echo -n ""
}

# will be called in on_exit, automatically added by make.sh
function on_exit_custom()
{
    echo -n ""
}

# only for vm
vm_runs=0
if [ -n "$(uname -m | egrep -oe 'i[0-9]{1}86')" ]; then
    vm_runs=1
fi

# call package install at first
custom_declared=1
install_packages install

echo "    <version>120268</version>" >> config/xml/innovaphone-exchange.xml
echo "    <hotfix>1</hotfix>" >> config/xml/innovaphone-exchange.xml
echo "</application>" >> config/xml/innovaphone-exchange.xml
xml_tmp=`mktemp /tmp/app_xml_XXXXXXXX`
./cp_template.sh 755 www-data www-data config/xml/innovaphone-exchange.xml /var/www/innovaphone/apps/innovaphone-exchange.xml ${xml_tmp}
echo -n "dvl" > /var/www/innovaphone/apps/innovaphone-exchange/dvl
 
 
echo -n 120268 > /var/www/innovaphone/apps/innovaphone-exchange/version
echo -n 1 > /var/www/innovaphone/apps/innovaphone-exchange/hotfix

# finish
if [ ${process} -eq 1 ] || [ ${lighttpd} -eq 1 ]; then
    if [ $1 ]; then
        echo 1 > /var/www/innovaphone/tmp/hotfix_lighttpd.restart
    else 
        log_msg "The web server will be restarted a few seconds after the installation!"
        log_msg "Installation was successful"
        sleep 10s
        php5-cgi /var/www/innovaphone/update_webserver_cfg.php
    fi
elif [ ! $1 ]; then
    log_msg "Installation was successful"
fi

on_exit
